@@ -4,26 +4,18 @@ Created on 7 Jul 2021
 @author: jacklok
 '''
 
-from flask import Blueprint, request, session, current_app, jsonify 
-from flask_restful import abort
+from flask import Blueprint, request
 import logging
 from trexlib.utils.log_util import get_tracelog
 from trexmodel.utils.model.model_util import create_db_client
 from datetime import datetime
-from trexapi.decorators.api_decorators import auth_token_required,\
-    outlet_key_required
 from trexlib.utils.string_util import is_not_empty
-from trexmodel.models.datastore.customer_models import Customer
 from trexmodel.models.datastore.user_models import User
 from trexadmin.libs.http import create_rest_message
 from trexadmin.libs.http import StatusCode
 from werkzeug.datastructures import ImmutableMultiDict
 from trexapi.forms.user_api_forms import UserRegistrationForm
-from trexmail.flask_mail import send_email
-from trexmail.conf import DEFAULT_SENDER
 from trexapi.conf import APPLICATION_NAME, APPLICATION_BASE_URL
-from datetime import timedelta
-import time
 from trexmail.email_helper import trigger_send_email
 
 user_api_bp = Blueprint('user_api_bp', __name__,
